@@ -48,13 +48,16 @@ NULL
 validClaytonCopula = function(object) {
   if (object@dimension != 2)
     return("Only Clayton copulas of dimension 2 are supported.")
-  param <- object@parameters
-  upper <- object@param.upbnd
-  lower <- object@param.lowbnd
-  if (length(param) != length(upper))
-    return("Parameter and upper bound have non-equal length")
-  if (length(param) != length(lower))
-    return("Parameter and lower bound have non-equal length")
+    param <- object@parameters
+    p.n <- length(param)
+    upper <- object@param.upbnd
+    lower <- object@param.lowbnd
+    if (p.n != length(upper))
+        return("Parameter and upper bound have non-equal length.")
+    if (p.n != length(lower))
+        return("Parameter and lower bound have non-equal length.")
+    if (p.n != length(object@param.names))
+        return("Parameter and parameter names have non-equal length.")
   if (any(is.na(param) | param >= upper | param <= lower ))
     return("Parameter value out of bound.")
   else return (TRUE)
@@ -136,7 +139,7 @@ setMethod("iTau", signature("surClaytonCopula"),
           })
 
 setMethod("tau",signature("surClaytonCopula"),linkVineCop.tau)
-setMethod("tailIndex",signature("surClaytonCopula"),linkVineCop.tailIndex)
+setMethod("lambda",signature("surClaytonCopula"),linkVineCop.tailIndex)
 
 #######################
 ## Clayton copula 90 ##
@@ -145,13 +148,16 @@ setMethod("tailIndex",signature("surClaytonCopula"),linkVineCop.tailIndex)
 validRotClaytonCopula = function(object) {
   if (object@dimension != 2)
     return("Only Clayton copulas of dimension 2 are supported.")
-  param <- object@parameters
-  upper <- object@param.upbnd
-  lower <- object@param.lowbnd
-  if (length(param) != length(upper))
-    return("Parameter and upper bound have non-equal length")
-  if (length(param) != length(lower))
-    return("Parameter and lower bound have non-equal length")
+    param <- object@parameters
+    p.n <- length(param)
+    upper <- object@param.upbnd
+    lower <- object@param.lowbnd
+    if (p.n != length(upper))
+        return("Parameter and upper bound have non-equal length.")
+    if (p.n != length(lower))
+        return("Parameter and lower bound have non-equal length.")
+    if (p.n != length(object@param.names))
+        return("Parameter and parameter names have non-equal length.")
   if (any(is.na(param) | param >= upper | param <= lower))
     return("Parameter value out of bound")
   else return (TRUE)
@@ -165,7 +171,7 @@ setClass("r90ClaytonCopula",
 
 # constructor
 r90ClaytonCopula <- function (param=-1) {
-  new("r90ClaytonCopula", dimension = as.integer(2), parameters = param, param.names = c("theta", "delta"),
+  new("r90ClaytonCopula", dimension = as.integer(2), parameters = param, param.names = "theta",
       param.lowbnd = -Inf, param.upbnd = 0, family=23,
       fullname = "90 deg rotated Clayton copula family. Number 23 in VineCopula.")
 }
@@ -211,7 +217,7 @@ setMethod("iTau", signature("r90ClaytonCopula"),
           })
 
 setMethod("tau",signature("r90ClaytonCopula"),linkVineCop.tau)
-setMethod("tailIndex",signature("r90ClaytonCopula"),linkVineCop.tailIndex)
+setMethod("lambda",signature("r90ClaytonCopula"),linkVineCop.tailIndex)
 
 ########################
 ## Clayton copula 270 ##
@@ -225,7 +231,7 @@ setClass("r270ClaytonCopula",
 
 # constructor
 r270ClaytonCopula <- function (param=-1) {
-  new("r270ClaytonCopula", dimension = as.integer(2), parameters = param, param.names = c("theta", "delta"),
+  new("r270ClaytonCopula", dimension = as.integer(2), parameters = param, param.names = "theta",
       param.lowbnd = -Inf, param.upbnd = 0, family=33,
       fullname = "270 deg rotated Clayton copula family. Number 33 in VineCopula.")
 }
@@ -272,7 +278,7 @@ setMethod("iTau", signature("r270ClaytonCopula"),
 
 setMethod("tau",signature("r270ClaytonCopula"),linkVineCop.tau)
 
-setMethod("tailIndex",signature("r270ClaytonCopula"),linkVineCop.tailIndex)
+setMethod("lambda",signature("r270ClaytonCopula"),linkVineCop.tailIndex)
 
 
 
@@ -320,13 +326,16 @@ NULL
 validGumbelCopula = function(object) {
   if (object@dimension != 2)
     return("Only Gumbel copulas of dimension 2 are supported.")
-  param <- object@parameters
-  upper <- object@param.upbnd
-  lower <- object@param.lowbnd
-  if (length(param) != length(upper))
-    return("Parameter and upper bound have non-equal length")
-  if (length(param) != length(lower))
-    return("Parameter and lower bound have non-equal length")
+    param <- object@parameters
+    p.n <- length(param)
+    upper <- object@param.upbnd
+    lower <- object@param.lowbnd
+    if (p.n != length(upper))
+        return("Parameter and upper bound have non-equal length.")
+    if (p.n != length(lower))
+        return("Parameter and lower bound have non-equal length.")
+    if (p.n != length(object@param.names))
+        return("Parameter and parameter names have non-equal length.")
   if (any(is.na(param) | param >= upper | param < lower ))
     return("Parameter value out of bound.")
   else return (TRUE)
@@ -413,7 +422,7 @@ setMethod("iTau", signature("surGumbelCopula"),
 
 setMethod("tau",signature("surGumbelCopula"),linkVineCop.tau)
 
-setMethod("tailIndex",signature("surGumbelCopula"),linkVineCop.tailIndex)
+setMethod("lambda",signature("surGumbelCopula"),linkVineCop.tailIndex)
 
 #######################
 ## Gumbel copula 90 ##
@@ -422,13 +431,16 @@ setMethod("tailIndex",signature("surGumbelCopula"),linkVineCop.tailIndex)
 validRotGumbelCopula = function(object) {
   if (object@dimension != 2)
     return("Only Gumbel copulas of dimension 2 are supported.")
-  param <- object@parameters
-  upper <- object@param.upbnd
-  lower <- object@param.lowbnd
-  if (length(param) != length(upper))
-    return("Parameter and upper bound have non-equal length")
-  if (length(param) != length(lower))
-    return("Parameter and lower bound have non-equal length")
+    param <- object@parameters
+    p.n <- length(param)
+    upper <- object@param.upbnd
+    lower <- object@param.lowbnd
+    if (p.n != length(upper))
+        return("Parameter and upper bound have non-equal length.")
+    if (p.n != length(lower))
+        return("Parameter and lower bound have non-equal length.")
+    if (p.n != length(object@param.names))
+        return("Parameter and parameter names have non-equal length.")
   if (any(is.na(param) | param > upper | param <= lower))
     return("Parameter value out of bound")
   else return (TRUE)
@@ -442,7 +454,7 @@ setClass("r90GumbelCopula",
 
 # constructor
 r90GumbelCopula <- function (param=-1) {
-  new("r90GumbelCopula", dimension = as.integer(2), parameters = param, param.names = c("theta", "delta"),
+  new("r90GumbelCopula", dimension = as.integer(2), parameters = param, param.names = "theta",
       param.lowbnd = -Inf, param.upbnd = -1, family=24,
       fullname = "90 deg rotated Gumbel copula family. Number 24 in VineCopula.")
 }
@@ -489,7 +501,7 @@ setMethod("iTau", signature("r90GumbelCopula"),
 
 setMethod("tau",signature("r90GumbelCopula"),linkVineCop.tau)
 
-setMethod("tailIndex",signature("r90GumbelCopula"),linkVineCop.tailIndex)
+setMethod("lambda",signature("r90GumbelCopula"),linkVineCop.tailIndex)
 
 ########################
 ## Gumbel copula 270 ##
@@ -503,7 +515,7 @@ setClass("r270GumbelCopula",
 
 # constructor
 r270GumbelCopula <- function (param=-1) {
-  new("r270GumbelCopula", dimension = as.integer(2), parameters = param, param.names = c("theta", "delta"),
+  new("r270GumbelCopula", dimension = as.integer(2), parameters = param, param.names = "theta",
       param.lowbnd = -Inf, param.upbnd = -1, family=34,
       fullname = "270 deg rotated Gumbel copula family. Number 34 in VineCopula.")
 }
@@ -550,4 +562,4 @@ setMethod("iTau", signature("r270GumbelCopula"),
 
 setMethod("tau",signature("r270GumbelCopula"),linkVineCop.tau)
 
-setMethod("tailIndex",signature("r270GumbelCopula"),linkVineCop.tailIndex)
+setMethod("lambda",signature("r270GumbelCopula"),linkVineCop.tailIndex)
